@@ -4,8 +4,10 @@ from .orders.orders import Orders
 from .product_fees.product_fees import ProductFees
 from .sellers.sellers import Sellers
 from .reports.reports import Reports
+from .products.products import Products
 
 __all__ = [
+    "Products",
     "Reports",
     "Orders",
     "Sellers",
